pub struct SnapSettings {
pub translation: Vec3,
pub rotation_radians: f32,
pub scale: Vec3,
}Expand description
Quantization increments for editor transforms. Zero disables a component.
Fields
translation: Vec3Translation increments per axis.
rotation_radians: f32Rotation increment in radians.
scale: Vec3Scale increments per axis.
Implementations
Sourceimpl SnapSettings
impl SnapSettings
Sourcepub fn snap_translation(self, delta: Vec3) -> Vec3
pub fn snap_translation(self, delta: Vec3) -> Vec3
Quantizes a translation relative to the operation start.
Sourcepub fn snap_rotation(self, radians: f32) -> f32
pub fn snap_rotation(self, radians: f32) -> f32
Quantizes a rotation angle relative to the operation start.
Sourcepub fn snap_scale(self, delta: Vec3) -> Vec3
pub fn snap_scale(self, delta: Vec3) -> Vec3
Quantizes a scale delta relative to the operation start.